@@ -4,7 +4,7 @@ from typing import Optional
 
 from dataclasses_json import dataclass_json
 
-from telescope_sdk.common import TelescopeBaseType
+from telescope_sdk.common import UserFacingDataType
 
 
 class CampaignLogEventType(Enum):
@@ -27,9 +27,8 @@ class CampaignLogEventType(Enum):
 
 @dataclass_json
 @dataclass
-class CampaignLogEvent(TelescopeBaseType):
+class CampaignLogEvent(UserFacingDataType):
     campaign_id: str
-    owner: str
     type: CampaignLogEventType
     description: Optional[str] = None
     prospect_id: Optional[str] = None
