@@ -4,7 +4,7 @@ from typing import Optional
 
 from dataclasses_json import dataclass_json
 
-from telescope_sdk.common import TelescopeBaseType
+from telescope_sdk.common import UserFacingDataType
 
 
 class RecommendationStatus(Enum):
@@ -14,18 +14,18 @@ class RecommendationStatus(Enum):
     PENDING = 'PENDING'
 
 
+# TODO: iterate on these field values
 class RecommendationRejectionReason(Enum):
-    ACCEPTED = 'ACCEPTED'
-    REJECTED = 'REJECTED'
-    SAVED = 'SAVED'
-    PENDING = 'PENDING'
+    EXISTING_CUSTOMER = 'EXISTING_CUSTOMER'
+    NOT_QUALIFIED = 'NOT_QUALIFIED'
+    OTHER = 'OTHER'
 
 
 @dataclass_json
 @dataclass
-class Recommendation(TelescopeBaseType):
+class Recommendation(UserFacingDataType):
     campaign_id: str
     person_id: str
     status: RecommendationStatus
     relevance: float
-    rejection_reason: Optional['RecommendationRejectionReason'] = None
+    rejection_reason: Optional[RecommendationRejectionReason] = None
