@@ -18,8 +18,8 @@ class SequenceStep:
     id: str
     type: SequenceStepType
     seconds_from_previous_step: int
-    subject: Optional[str] = None
-    body: Optional[str] = None
+    subject: str
+    body: str
     signature: Optional[str] = None
 
 
